@@ -28,7 +28,7 @@ from rqsdk.script_update import pip_install
 @click.help_option("-h", "--help")
 def cli():
     """
-    输入 rqsdk <COMMAND> --help 查看命令详情
+    输入 rqsdk [COMMAND] --help 查看命令详情
     例如：rqsdk install --help
     """
     pass
@@ -62,15 +62,23 @@ def license(rqdatac_uri):
 
 @cli.command()
 @click.argument('product', default="", nargs=1)
-@click.option('-i', '--index-url', default="https://pypi.douban.com/simple/", help="指定默认源")
+@click.option('-i', '--index-url', default="https://pypi.douban.com/simple/", help="指定默认源", hidden=True)
 def update(product, index_url):
     """
     更新 rqsdk 及使用 rqsdk 安装的产品。
 
     \b
-    输入 rqsdk update [<PRODUCT>] 安装对应产品，PRODUCT为空时默认更新已安装产品。例如 rqsdk update rqoptimizer。
-    PRODUCT可选: rqdatac | rqfactor | rqoptimizer | rqalpha_plus
+    输入 rqsdk update <PRODUCT> 安装对应产品，<PRODUCT> 为空时默认更新已安装产品。例如:
+        rqsdk update rqdatac
+        rqsdk update
 
+    <PRODUCT> 可选: rqdatac | rqfactor | rqoptimizer | rqalpha_plus
+
+    \b
+    * rqdatac - 金融数据API（默认已安装）
+    * rqalpha_plus - 多资产回测引擎
+    * rqoptimizer - 股票优化器
+    * rqfactor - 因子投研和检验
     """
     if product != "":
         if product not in VERSION_MAP.keys():
@@ -101,14 +109,18 @@ def update(product, index_url):
 
 @cli.command()
 @click.argument('product', default="", nargs=1)
-@click.option('-i', '--index-url', default="https://pypi.douban.com/simple/", help="指定默认源")
+@click.option('-i', '--index-url', default="https://pypi.douban.com/simple/", help="指定默认源", hidden=True)
 def install(product, index_url):
     """
     安装产品。
 
     \b
-    输入 rqsdk install <PRODUCT> 安装对应产品。例如 rqsdk install rqoptimizer。
-    PRODUCT 可选: rqdatac | rqfactor | rqoptimizer | rqalpha_plus
+    输入 rqsdk install <PRODUCT> 安装对应产品。例如:
+        rqsdk install rqdatac。
+
+    <PRODUCT> 可选: rqdatac | rqfactor | rqoptimizer | rqalpha_plus
+
+    \b
     * rqdatac - 金融数据API（默认已安装）
     * rqalpha_plus - 多资产回测引擎
     * rqoptimizer - 股票优化器
